%define _requires_exceptions pear(*

%define name mss
%define version 2.4
%define release 0.6
%define git 6d1ec4c-master
%define date 20160420
%global username mss
%global groupname mss

Summary:       Management Server Setup
URL:           https://github.com/pulse-project/mss
Name:          %{name}
Version:       %{version}
Release:       %mkrel %{release}
Source0:       %{name}-%{version}-%git-%date.tar.gz
Source1:       mss.conf
Source4:       logrotate.conf
Source5:       99info.sh
Source6:       mss.filter
Source7:       mss.script
Source8:       mss-urpmi.tmpfiles
License:       GPLv3 and MIT and ASL 2.0
Group:         System/Servers
BuildArch:     noarch

BuildRequires:   pkgconfig(python2)
BuildRequires:   pythonegg(2)(setuptools)

Requires(pre):   shadow-utils
Requires(pre):   python-django
Requires(pre):   rpm-helper
Requires(post):  rpm-helper
Requires(preun): rpm-helper
Requires(postun): rpm-helper
Requires:        python
Requires:        python-IPy
Requires:        python-OpenSSL
Requires:        openssl
Requires:        binutils
Requires:        python-netifaces
Requires:        python-cherrypy >= 3.2.2
Requires:        wget
Requires:        python-sqlalchemy >= 0.7
Requires:        python-markdown
Requires:        apache

Requires:        locales-fr locales-de locales-pt locales-zh


Provides:        mss-agents
Obsoletes:       mss-agents
Obsoletes:       mss-modules-base

%description
MSS aims to help system administrators to quickly setup services.

%pre
# Add mss user
mkdir -p %_var/lib/mss
%_pre_useradd %username %_var/lib/mss /sbin/nologin
%_pre_groupadd %groupname %username


%post
%_tmpfilescreate %name

if [ $1 = 1 ]; then

    #Create secrete key
    SALT=`</dev/urandom tr -dc A-Za-z0-9 | head -c 50`
    sed -i "s/^SECRET_KEY.*/SECRET_KEY = \"${SALT}\"/" %{py_puresitedir}/mss/www/local_settings.py

    # Generate SSL certs
    umask 077
    if [ ! -f %{_sysconfdir}/mss/ssl/localhost.key ]; then
        %{_bindir}/openssl genrsa -rand /proc/apm:/proc/cpuinfo:/proc/dma:/proc/filesystems:/proc/interrupts:/proc/ioports:/proc/pci:/proc/rtc:/proc/uptime 1024 > %{_sysconfdir}/mss/ssl/localhost.key 2> /dev/null
        chown mss.mss %{_sysconfdir}/mss/ssl/localhost.key
    fi

    FQDN=`hostname -f`
    if [ "x${FQDN}" = "x" ]; then
        FQDN=localhost.localdomain
    fi

    if [ ! -f %{_sysconfdir}/mss/ssl/localhost.crt ] ; then
        cat << EOF | %{_bindir}/openssl req -new -key %{_sysconfdir}/mss/ssl/localhost.key -x509 -days 365 -set_serial $RANDOM -out %{_sysconfdir}/mss/ssl/localhost.crt 2>/dev/null
--
SomeState
SomeCity
Mageia
Mageia.org
${FQDN}
root@${FQDN}
EOF
        chown mss.mss %{_sysconfdir}/mss/ssl/localhost.crt
    fi

    # create BDD
    %{__python2} %{python2_sitelib}/mss/www/manage.py syncdb --noinput
    chown mss /var/lib/mss/mss-www.db
fi

# install/upgrade
if [ $1 -ge 1 ]; then
    %_post_service mss-agent
    %_post_service mss-www
fi
# clear json cache
rm -f /var/lib/mss/cache/*.json
exit 0


%preun
# package uninstallation
if [ $1 -eq 0 ]; then
    %_preun_service mss-agent
    %_preun_service mss-www
fi

%postun
%_postun_userdel %username
%_postun_groupdel %groupname

# automatic reload mss-agent if new modules are installed.
%transfiletriggerin -- /usr/lib/python2.[0-9]+/site-packages/mss/
/usr/sbin/service mss-agent restart
/usr/sbin/service mss-www restart

%files
%doc %_datadir/doc/mss/LICENCE
%_sysconfdir/profile.d/99info.sh
# we want to replace this one on update
%config %_sysconfdir/mss/agent.ini
%{_unitdir}/mss-www.service
%{_unitdir}/mss-agent.service
%{_sbindir}/mss-agent*
%{_bindir}/mss-www
%{_sbindir}/mss-add-shorewall-rule
%{python2_sitelib}/mss*egg-info/
%{python2_sitelib}/mss/
%attr(-,%username,root) %{_var}/lib/mss
%attr(-,root,root) %{_var}/lib/mss/local
%{_var}/lib/mss/cache/functions.sh
%{_var}/log/mss
%config(noreplace) %attr(0640,%username,%groupname)%{_localstatedir}/log/mss/mss-www.log
%config(noreplace) %attr(0640,root,root)%{_localstatedir}/log/mss/mss-agent.log
%{_sysconfdir}/mss/ssl/
%config %{_sysconfdir}/httpd/conf/webapps.d/mss.conf
%config %{_sysconfdir}/logrotate.d/mss-agent
%config(noreplace) %{py_puresitedir}/mss/www/local_settings.py
%{_tmpfilesdir}/%name.conf

#--------------------------------------------------------------------

%prep
%setup -q -n %{name}-%{version}-%git-%date
%autopatch -p1

%build
%py2_build

%install
%define install_parameters --single-version-externally-managed
%py2_install %install_parameters

# init scripts
install -d %{buildroot}%{_unitdir}
install -d %{buildroot}%{_sbindir}
install -d %{buildroot}%{_bindir}
install -m0644 bin/www/mss-www.service %{buildroot}%{_unitdir}/
install -m0644 bin/agent/mss-agent.service %{buildroot}%{_unitdir}/
install -m0755 bin/www/mss-www.sh %{buildroot}%{_bindir}/mss-www

# XML-RPC daemon
install -d %{buildroot}%{_sbindir}
install -m0755 bin/agent/mss-agent.py %{buildroot}%{_sbindir}/mss-agent
install -m0755 bin/mss-add-shorewall-rule %{buildroot}%{_sbindir}/

# logrotate configuration
install -d %{buildroot}%{_sysconfdir}/logrotate.d/
install -m0644 %{SOURCE4} %{buildroot}%{_sysconfdir}/logrotate.d/mss-agent

# databases directory
install -d %{buildroot}%{_var}/lib/mss/

# logs directory for mss-agent and mss-www
install -d %{buildroot}%{_logdir}/mss/
touch %{buildroot}%{_logdir}/mss/mss-www.log
touch %{buildroot}%{_logdir}/mss/mss-agent.log

# Directory for SSL certificates
install -d %{buildroot}%{_sysconfdir}/mss/ssl/

# Documentation
install -d %{buildroot}%{_datadir}/doc/mss/html/
install -d %{buildroot}%{_datadir}/doc/mss/html/_images/
install -d %{buildroot}%{_datadir}/doc/mss/html/_sources/
install -d %{buildroot}%{_datadir}/doc/mss/html/_static/
install -m0644 LICENCE %{buildroot}%{_datadir}/doc/mss/

# www configuration
cp %{buildroot}%{python2_sitelib}/mss/www/local_settings.py.example %{buildroot}%{python2_sitelib}/mss/www/local_settings.py

# mss modules
install -d %{buildroot}%{_var}/lib/mss/
cp -frv modules %{buildroot}%{_var}/lib/mss/local
install -d %{buildroot}%{_var}/lib/mss/cache/
cp -frv modules/functions.sh %{buildroot}%{_var}/lib/mss/cache/

# directory for API modules
install -d %{buildroot}%{_var}/lib/mss/cache

# agent configuration
install -m0644 etc/agent.ini %{buildroot}%{_sysconfdir}/mss/agent.ini

install -d %{buildroot}%{_sysconfdir}/profile.d/
install -m0644 %{SOURCE5} %{buildroot}%{_sysconfdir}/profile.d/

# apache redirect to MSS
install -d %{buildroot}%{_sysconfdir}/httpd/conf/webapps.d/
install -m0644 %{SOURCE1} %{buildroot}%{_sysconfdir}/httpd/conf/webapps.d/

# directory for mounting repo media
mkdir -p %{buildroot}%{_tmpfilesdir}
install -D -m 644 %{SOURCE8} %{buildroot}%{_tmpfilesdir}/%name.conf

# Remove Pulse2
rm -frv %{buildroot}%{_var}/lib/mss/local/pulse2




%changelog
* Wed Apr 20 2016 neoclust <neoclust> 2.4-0.6.mga6
+ Revision: 1003739
- New snapshot, fix ldap configuration

* Tue Feb 16 2016 neoclust <neoclust> 2.4-0.5.mga6
+ Revision: 962393
- New snapshot
  Fix deps in pulse2 module

* Fri Jan 22 2016 neoclust <neoclust> 2.4-0.4.mga6
+ Revision: 926547
- Include pulse2 module

* Sun Jan 17 2016 daviddavid <daviddavid> 2.4-0.3.mga6
+ Revision: 925010
- use new python macros

* Sun Jan 17 2016 neoclust <neoclust> 2.4-0.2.mga6
+ Revision: 924996
- Fix URL

* Sun Jan 17 2016 neoclust <neoclust> 2.4-0.1.mga6
+ Revision: 924985
- imported package mss

